@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+from django.test import TestCase
 
 from allauth.socialaccount.tests import OAuth2TestsMixin
-from allauth.tests import MockedResponse, TestCase
+from allauth.tests import MockedResponse
 
 from .provider import BoxOAuth2Provider
 
@@ -34,3 +33,6 @@ class BoxOAuth2Tests(OAuth2TestsMixin, TestCase):
         }""",
             )
         ]
+
+    def get_expected_to_str(self):
+        return "balls@example.com"
