@@ -1,6 +1,8 @@
+from django.test import TestCase
+
 from allauth.socialaccount.providers.miro.provider import MiroProvider
 from allauth.socialaccount.tests import OAuth2TestsMixin
-from allauth.tests import MockedResponse, TestCase
+from allauth.tests import MockedResponse
 
 
 class MiroTests(OAuth2TestsMixin, TestCase):
@@ -24,3 +26,6 @@ class MiroTests(OAuth2TestsMixin, TestCase):
                 }
             }""",
         )
+
+    def get_expected_to_str(self):
+        return "oborin.p@gmail.com"
